@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.25.2.1 2004/05/04 13:52:30 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.25.2.4 2004/11/13 09:38:21 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -51,6 +51,17 @@ extern "C" {
 #define IS_BBS_THREAD_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE((klass), BBS_THREAD_VIEW_TYPE))
 #define BBS_THREAD_VIEW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), BBS_THREAD_VIEW_TYPE, BBSThreadViewClass))
 
+#define BBS_THREAD_VIEW_SCROLL_TO_TYPE		(bbs_thread_view_scroll_to_get_type())
+
+typedef enum
+{
+  SCROLL_TO_BUFFER_START,
+  SCROLL_TO_BUFFER_END
+} BBSThreadViewScrollTo;
+
+
+GType bbs_thread_view_scroll_to_get_type(void) G_GNUC_CONST;
+
 
 typedef struct _BBSThreadView BBSThreadView;
 typedef struct _BBSThreadViewClass BBSThreadViewClass;
@@ -76,9 +87,12 @@ struct _BBSThreadView
 
   GtkTextBuffer *text_buffer;
 
+  GdkCursor *normal_cursor;
   GdkCursor *ibeam_cursor;
   GdkCursor *hand_cursor;
 
+  GdkCursor *nonlink_cursor;
+
   /* Хåե˻Ȥ */
   GtkTextIter iter;
   GSList *tags;
@@ -120,28 +134,25 @@ struct _BBSThreadViewClass
 
   GtkTextTagTable *tag_table;
 
-  void (*link_mouse_over)(BBSThreadView *bbs_thread_view,
-			  GdkEventMotion *event,
+  void (*link_mouse_over)(BBSThreadView *view, GdkEventMotion *event,
 			  OchushaBBSThread *thread, const gchar *link);
-  void (*link_mouse_out)(BBSThreadView *bbs_thread_view,
-			 GdkEventAny *event, OchushaBBSThread *thread);
-  gboolean (*link_mouse_press)(BBSThreadView *bbs_therad_view,
-			       GdkEventButton *event,
+  void (*link_mouse_out)(BBSThreadView *view, GdkEventAny *event,
+			 OchushaBBSThread *thread);
+  gboolean (*link_mouse_press)(BBSThreadView *view, GdkEventButton *event,
 			       OchushaBBSThread *thread, const gchar *link);
-  gboolean (*link_mouse_release)(BBSThreadView *bbs_thread_view,
-				 GdkEventButton *event,
+  gboolean (*link_mouse_release)(BBSThreadView *view, GdkEventButton *event,
 				 OchushaBBSThread *thread, const gchar *link);
 
-  void (*scroll_to)(BBSThreadView *bbs_thread_view, int to_where);
-  void (*scroll_view)(BBSThreadView *bbs_thread_view, GtkScrollType scroll);
-  void (*interactive_search)(BBSThreadView *bbs_thread_view,
+  void (*scroll_to)(BBSThreadView *view, BBSThreadViewScrollTo where);
+  void (*scroll_view)(BBSThreadView *view, GtkScrollType scroll);
+  void (*interactive_search)(BBSThreadView *view,
 			     BBSThreadViewSearchAction action);
-  void (*write_response)(BBSThreadView *bbs_thread_view);
-  void (*close_thread)(BBSThreadView *bbs_thread_view);
+  void (*write_response)(BBSThreadView *view);
+  void (*close_thread)(BBSThreadView *view);
 };
 
 
-GType bbs_thread_view_get_type(void);
+GType bbs_thread_view_get_type(void) G_GNUC_CONST;
 
 GtkTextTagTable *bbs_thread_view_class_get_default_tag_table(BBSThreadViewClass *klass);
 
@@ -149,6 +160,8 @@ GtkWidget *bbs_thread_view_new(OchushaBBSThread *thread);
 void bbs_thread_view_set_thread(BBSThreadView *view, OchushaBBSThread *thread);
 OchushaBBSThread *bbs_thread_view_get_thread(BBSThreadView *view);
 
+char *bbs_thread_view_get_selected_text(BBSThreadView *view);
+
 void bbs_thread_view_clear(BBSThreadView *view);
 
 int bbs_thread_view_get_current_offset(BBSThreadView *view);
@@ -199,7 +212,6 @@ gboolean bbs_thread_view_find_next(BBSThreadView *view);
 void bbs_thread_view_invalidate_search_result(BBSThreadView *view);
 
 
-
 #ifdef __cplusplus
 } // extern "C"
 #endif
