@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.92.2.8 2004/11/13 12:40:52 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.92.2.9 2005/02/18 17:33:16 fuyu Exp $
  */
 
 #define _BOARDLIST_UI_C_ 1
@@ -406,10 +406,6 @@ initialize_boardlist(OchushaApplication *application)
   scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
 				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-#if 0	/* themeǤˤޤ٤ */
-  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window),
-				      GTK_SHADOW_ETCHED_IN);
-#endif
   gtk_container_add(GTK_CONTAINER(scrolled_window),
 		    application->boardlist_view);
 
@@ -480,7 +476,8 @@ initialize_boardlist(OchushaApplication *application)
 			   application,
 			   0);
 #else
-  action_group = PANED_NOTEBOOK(application->contents_window)->action_group;
+  action_group = gtk_action_group_new("ThreadlistToolbarActions");
+  gtk_action_group_set_translation_domain(action_group, PACKAGE_NAME);
   gtk_action_group_add_actions(action_group,
 			       toolbar_entries,
 			       G_N_ELEMENTS(toolbar_entries),
@@ -489,8 +486,9 @@ initialize_boardlist(OchushaApplication *application)
 				      toolbar_toggle_entries,
 				      G_N_ELEMENTS(toolbar_toggle_entries),
 				      application);
-
   ui_manager = PANED_NOTEBOOK(application->contents_window)->ui_manager;
+  gtk_ui_manager_insert_action_group(ui_manager, action_group, 0);
+  g_object_unref(action_group);
 
   error = NULL;
   if (!gtk_ui_manager_add_ui_from_string(ui_manager,
