@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: download_ui.h,v 1.2 2004/01/19 00:38:47 fuyu Exp $
+ * $Id: download_ui.h,v 1.3 2004/01/23 18:51:11 fuyu Exp $
  */
 
 #ifndef _DOWNLOAD_UI_H_
@@ -35,8 +35,6 @@ extern "C" {
 
 void initialize_download_ui(OchushaApplication *application);
 void ochusha_download_url(OchushaApplication *application, const char *url);
-GtkWidget *ochusha_download_image(OchushaApplication *application,
-				  const char *url, int width, int height);
 
 #ifdef __cplusplus
 } // extern "C"
