@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 The Ochusha Project.
+ * Copyright (c) 2003-2004 The Ochusha Project.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: icon_label.c,v 1.4 2003/12/30 21:53:28 fuyu Exp $
+ * $Id: icon_label.c,v 1.5.2.1 2005/02/18 17:33:16 fuyu Exp $
  */
 
 #include "icon_label.h"
@@ -141,7 +141,7 @@ icon_label_destroy(GtkObject *object)
 
   if (icon_label->icon != NULL)
     {
-      OCHU_OBJECT_UNREF(G_OBJECT(icon_label->icon));
+      g_object_unref(icon_label->icon);
       icon_label->icon = NULL;
     }
 
@@ -241,12 +241,15 @@ icon_label_expose(GtkWidget *widget, GdkEventExpose *event)
 GtkWidget *
 icon_label_new(const gchar *label_text, GdkPixbuf *icon)
 {
-  GtkWidget *widget = g_object_new(ICON_LABEL_TYPE, "label", label_text, NULL);
+  GtkWidget *widget = g_object_new(ICON_LABEL_TYPE,
+				   "label", label_text,
+				   "xalign", 0.0,
+				   NULL);
   IconLabel *icon_label = ICON_LABEL(widget);
 
   if (icon != NULL)
     {
-      OCHU_OBJECT_REF(G_OBJECT(icon));
+      g_object_ref(icon);
       icon_label->icon = icon;
     }
 
@@ -263,10 +266,10 @@ icon_label_set_icon(IconLabel *icon_label, GdkPixbuf *icon)
     return;
 
   if (icon_label->icon != NULL)
-    OCHU_OBJECT_UNREF(G_OBJECT(icon_label->icon));
+    g_object_unref(icon_label->icon);
 
   if (icon != NULL)
-    OCHU_OBJECT_REF(G_OBJECT(icon));
+    g_object_ref(icon);
 
   icon_label->icon = icon;
   gtk_widget_queue_resize(GTK_WIDGET(icon_label));
