@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: icon_label.h,v 1.5 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: icon_label.h,v 1.5.2.1 2004/06/11 12:02:34 fuyu Exp $
  */
 
 #ifndef _ICON_LABEL_H_
@@ -64,7 +64,7 @@ struct _IconLabelClass
 };
 
 
-GType icon_label_get_type(void);
+GType icon_label_get_type(void) G_GNUC_CONST;
 
 GtkWidget *icon_label_new(const gchar *label_text, GdkPixbuf *icon);
 void icon_label_set_icon(IconLabel *icon_label, GdkPixbuf *icon);
