@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.76.2.7 2004/11/24 00:01:28 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.76.2.8 2005/06/06 19:00:13 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -76,6 +76,7 @@
 
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_TITLE				FALSE
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE				TRUE
+#define OCHUSHA_DEFAULT_ENABLE_POPUP_ID					FALSE
 
 #define OCHUSHA_DEFAULT_POPUP_DELAY					500
 #define OCHUSHA_DEFAULT_POPUP_CLOSE_DELAY				100
@@ -274,6 +275,7 @@ struct _OchushaApplication
   int maximum_number_of_popup_responses;
   gboolean analyze_informal_links;
 
+  gboolean enable_popup_id;
 
   /* Ϣ */
   int inline_image_width;
