@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_filter.h,v 1.6 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: threadlist_filter.h,v 1.6.2.1 2004/06/11 12:02:34 fuyu Exp $
  */
 
 #ifndef _THREADLIST_FILTER_H_
@@ -156,7 +156,7 @@ struct _ThreadlistFilterSettingClass
 };
 
 
-GType threadlist_filter_setting_get_type(void);
+GType threadlist_filter_setting_get_type(void) G_GNUC_CONST;
 GtkWidget *threadlist_filter_setting_new(void);
 GtkWidget *threadlist_filter_setting_new_with_initial_setting(const ThreadlistFilter *filter);
 
