@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: xsmp.c,v 1.4 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: xsmp.c,v 1.5 2004/01/21 17:28:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,7 @@
 #include "ochusha_private.h"
 #include "ochusha.h"
 #include "ochusha_async_buffer.h"
+#include "worker.h"
 
 #include "ochusha_ui.h"
 #include "xsmp.h"
@@ -251,6 +252,7 @@ die_cb(SmcConn smc_conn, SmPointer client_data)
   application->smc_connection = NULL;
 
   ochusha_async_buffer_suspend_all();
+  cancel_pending_jobs();
   ochusha_async_buffer_terminate_all();
 
   gtk_main_quit();
