@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.c,v 1.14.2.2 2004/11/25 08:57:33 fuyu Exp $
+ * $Id: htmlutils.c,v 1.14.2.3 2004/12/30 16:55:41 fuyu Exp $
  */
 
 #include "config.h"
@@ -1086,28 +1086,6 @@ fake_anchor_tag(ElementHandler *handler, void *context, const char *head,
   else
     abort();	/* ꤨϤ */
 
-#if ENABLE_SKIP_IME_NU
-  /*
-   * ime.nuϼΤƼΤơ
-   */
-  while (TRUE)
-    {
-      if (len > 7 && g_ascii_strncasecmp(cur_pos, "ime.nu/", 7) == 0)
-	{
-	  cur_pos += 7;
-	  len -= 7;
-	  continue;
-	}
-      if (len > 14 && g_ascii_strncasecmp(cur_pos, "pinktower.com/", 14) == 0)
-	{
-	  cur_pos += 14;
-	  len -= 14;
-	  continue;
-	}
-      break;
-    }
-#endif
-
   tail = cur_pos;
   tmp_len = len;
 
