@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.17.2.3 2004/05/24 09:58:46 fuyu Exp $
+ * $Id: ochusha.h,v 1.17.2.5 2004/12/30 14:15:50 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -59,6 +59,8 @@ extern "C" {
 #define OCHUSHA_DOLIB_X_2CH_UA		"Ochusha/" VERSION
 #define OCHUSHA_CA_BUNDLE_CRT		PKGDATADIR "/ca-bundle.crt"
 
+#define OCHUSHA_2CH_BE_LOGIN_URL	"http://be.2ch.net/test/login.php"
+
 
 /*
  * 2ch1000쥹¤ΤǡѤʾ1024
@@ -88,6 +90,11 @@ struct _OchushaConfig
   gboolean login_2ch;
   char *session_id_2ch;
 
+  char *login_2ch_be_url;
+  char *session_id_2ch_be;
+
+  gboolean use_2ch_be_id_for_2ch;
+
 
   /* proxyϢ */
   gboolean enable_proxy;
