@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.25 2004/04/13 15:38:05 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.25.2.1 2004/06/11 12:00:48 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -148,7 +148,7 @@ typedef enum
 } OchushaBBSThreadState;
 
 
-GType ochusha_bbs_thread_get_type(void);
+GType ochusha_bbs_thread_get_type(void) G_GNUC_CONST;
 OchushaBBSThread *ochusha_bbs_thread_new(OchushaBulletinBoard *board,
 					 const char *thread_id,
 					 const gchar *title);
