@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.28.2.3 2004/05/24 10:04:39 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.28.2.4 2004/12/30 14:15:50 fuyu Exp $
  */
 
 #include "config.h"
@@ -1069,6 +1069,7 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, bbsmenu_url);
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, login_2ch_url);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, use_2ch_be_id_for_2ch);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, offline);
 
@@ -1128,6 +1129,8 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
     {
       config->bbsmenu_url = G_STRDUP(OCHUSHA_DEFAULT_BBSMENU_URL);
       config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
+      config->use_2ch_be_id_for_2ch = FALSE;
+
       config->offline = FALSE;
 
       config->enable_proxy = FALSE;
@@ -1182,6 +1185,9 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
 	  config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
 	}
 
+      config->use_2ch_be_id_for_2ch
+	= ochusha_utils_get_attribute_boolean(pref, "use_2ch_be_id_for_2ch");
+
       config->offline = ochusha_utils_get_attribute_boolean(pref, "offline");
 
       config->enable_proxy
