@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.71.2.2 2004/06/26 18:53:37 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.71.2.10 2005/08/01 06:07:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -52,6 +52,17 @@
 #include <zlib.h>
 
 
+#if HAVE_ONIG_ONIGURUMA_H
+# include <onig/oniguruma.h>
+#else
+# include <oniguruma.h>
+#endif
+
+#if (ONIGURUMA_VERSION_MAJOR < 2) && (ONIGURUMA_VERSION_MINOR < 2)
+#error "Please use included oniguruma, we no longer support oniguruma prior to 2.2"
+#endif
+
+
 #define DEBUG_DAT	0
 #define DEBUG_DAT_MOST	0
 
@@ -153,6 +164,11 @@ static OchushaBBSThreadClass *parent_class = NULL;
 static GQuark idle_checker_id;
 
 
+static const char * const be_link_pattern_string
+    = "<?BE:([0-9]+)[:-]([0-9]+|#*)>?";
+static const char *be_link_pattern_end = NULL;
+
+
 static void
 ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
 {
@@ -193,6 +209,10 @@ ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
 
   idle_checker_id
     = g_quark_from_static_string("OchushaThread2ch::IdleChecker");
+
+  if (be_link_pattern_end == NULL)
+    be_link_pattern_end
+      = be_link_pattern_string + strlen(be_link_pattern_string);
 }
 
 
@@ -206,6 +226,7 @@ ochusha_thread_2ch_init(OchushaThread2ch *thread)
 
   thread->responses = NULL;
 
+  thread->date = -1;
   thread->alive = FALSE;
 
   g_signal_connect(thread,
@@ -266,12 +287,6 @@ ochusha_thread_2ch_finalize(GObject *object)
       thread->last_modified = NULL;
     }
 
-  if (thread->date != NULL)
-    {
-      G_FREE(thread->date);
-      thread->date = NULL;
-    }
-
   if (G_OBJECT_CLASS(parent_class)->finalize)
     (*G_OBJECT_CLASS(parent_class)->finalize)(object);
 }
@@ -509,8 +524,18 @@ ochusha_thread_2ch_get_base_url(OchushaBBSThread *thread)
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), NULL);
 
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
+#if 0
   if (thread_2ch->base_url != NULL && thread_2ch->kako_html == NULL)
     return thread_2ch->base_url;
+#else
+  if (thread_2ch->base_url != NULL)
+    {
+      /* URLΥå᤿call siteľƤޤΤ
+       * ݤʤΤǡad-hoc˽*/
+      G_FREE(thread_2ch->base_url);
+      thread_2ch->base_url = NULL;
+    }
+#endif
 
   base_path = ochusha_thread_2ch_get_base_path(thread_2ch);
 
@@ -547,11 +572,19 @@ ochusha_thread_2ch_get_base_path(OchushaThread2ch *thread_2ch)
       char base_path[PATH_MAX];
       g_return_val_if_fail(thread->board != NULL && thread->id != NULL, NULL);
 
+#if 1
+      if (snprintf(base_path, PATH_MAX, "%stest/read.cgi/%s/%s/",
+		   ochusha_bulletin_board_get_base_path(thread->board),
+		   ochusha_bulletin_board_get_id(thread->board),
+		   thread->id) < PATH_MAX)
+	thread_2ch->base_path = G_STRDUP(base_path);
+#else
       if (snprintf(base_path, PATH_MAX, "/test/read.cgi%s%s/%s/",
 		   ochusha_bulletin_board_get_base_path(thread->board),
 		   ochusha_bulletin_board_get_id(thread->board),
 		   thread->id) < PATH_MAX)
 	thread_2ch->base_path = G_STRDUP(base_path);
+#endif
     }
 
   return thread_2ch->base_path;
@@ -1258,6 +1291,10 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
   gboolean result = TRUE;
   OchushaNetworkBrokerBufferStatus *status;
   OchushaNetworkBrokerBufferStatus fake_status;
+#if 1
+  regex_t *be_pattern = NULL;
+  OnigRegion *match_region = NULL;
+#endif
 
   g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread)
 		       && OCHUSHA_IS_ASYNC_BUFFER(buffer), FALSE);
@@ -1282,6 +1319,18 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
       return FALSE;
     }
 
+#if 1
+  if (onig_new(&be_pattern,
+	       (char *)be_link_pattern_string, (char *)be_link_pattern_end,
+	       ONIG_OPTION_NONE, ONIG_ENCODING_SJIS,
+	       ONIG_SYNTAX_RUBY, NULL) != ONIG_NORMAL)
+    {
+      fprintf(stderr, "invalid regular expression in be_link_pattern.\n");
+      be_pattern = NULL;
+    }
+  match_region = onig_region_new();
+#endif
+
   thread_2ch = OCHUSHA_THREAD_2CH(thread);
 
   responses = thread_2ch->responses;
@@ -1404,8 +1453,64 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 		if (title_pos != NULL)
 		  {
 		    if (each_response_cb != NULL)
-		      result = (*each_response_cb)(thread, i, &response,
-						   callback_data);
+		      {
+			char *date_id = (char *)response.date_id;
+			char *date_id_end = date_id + strlen(response.date_id);
+
+			if (onig_search(be_pattern,
+					date_id, date_id_end,
+					date_id, date_id_end,
+					match_region, 0) >= 0)
+			  {
+			    /*
+			     * BEdate_id񤭴롣
+			     */
+			    char *tmp_date_id;
+			    char lv_buf[128];
+			    size_t prof_len
+			      = match_region->end[1] - match_region->beg[1];
+			    char *profile
+			      = g_strndup(date_id + match_region->beg[1],
+					  prof_len);
+			    size_t lv_len
+			      = match_region->end[2] - match_region->beg[2];
+			    char url_buf[PATH_MAX];
+
+			    if (lv_len == 0
+				|| date_id[match_region->beg[2]] == '#')
+			      {
+				int j = 0;
+				char *lv_pos = date_id + match_region->beg[2];
+				while (*lv_pos++ == '#')
+				  j++;
+				snprintf(lv_buf, 128, "%d", j);
+			      }
+			    else
+			      {
+				date_id[match_region->end[2]] = '\0';
+				snprintf(lv_buf, 128, "%s",
+					 date_id + match_region->beg[2]);
+			      }
+			    date_id[match_region->beg[0]] = '\0';
+			    snprintf(url_buf, PATH_MAX, "%s%d",
+				     ochusha_bbs_thread_get_url(thread), i);
+			    tmp_date_id
+			      = g_strconcat(date_id,
+					    "<a href=\"http://be.2ch.net/test/p.php?i=",
+					    profile, "&u=d:",
+					    url_buf, "\">Lv.", lv_buf, "</a>",
+					    date_id + match_region->end[0],
+					    NULL);
+#if 0
+			    fprintf(stderr, "BE:%s\n", tmp_date_id);
+#endif
+			    g_free(date_id);
+			    g_free(profile);
+			    response.date_id = tmp_date_id;
+			  }
+			result = (*each_response_cb)(thread, i, &response,
+						     callback_data);
+		      }
 #if 0
 		    /*
 		     * Ƴ()ߤʤΤǡᡣ
@@ -1514,24 +1619,27 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	    /*
 	     * GUIΥ쥹ݥ󥹤βܻؤ¸
 	     */
-	    OCHU_OBJECT_REF(buffer);
-	    g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
-	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
-			    advance_parsing, buffer, NULL);
-	    if (before_wait_cb != NULL)
-	      (*before_wait_cb)(callback_data);
-	    do
+	    if (!no_wait)
 	      {
-		if (!ochusha_async_buffer_wait(buffer))
+		OCHU_OBJECT_REF(buffer);
+		g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
+		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
+				advance_parsing, buffer, NULL);
+		if (before_wait_cb != NULL)
+		  (*before_wait_cb)(callback_data);
+		do
 		  {
-		    if (after_wait_cb != NULL)
-		      (*after_wait_cb)(callback_data);
-		    goto terminated;
-		  }
-	      } while (g_object_get_qdata(G_OBJECT(buffer), idle_checker_id)
-		       != NULL);
-	    if (after_wait_cb != NULL)
-	      (*after_wait_cb)(callback_data);
+		    if (!ochusha_async_buffer_wait(buffer))
+		      {
+			if (after_wait_cb != NULL)
+			  (*after_wait_cb)(callback_data);
+			goto terminated;
+		      }
+		  } while (g_object_get_qdata(G_OBJECT(buffer),
+					      idle_checker_id) != NULL);
+		if (after_wait_cb != NULL)
+		  (*after_wait_cb)(callback_data);
+	      }
 	    interval = ANALYSIS_INTERVAL;
 	  }
 
@@ -1566,11 +1674,7 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 	}
 
       if (status->date != NULL)
-	{
-	  if (thread_2ch->date != NULL)
-	    G_FREE(thread_2ch->date);
-	  thread_2ch->date = G_STRDUP(status->date);
-	}
+	thread_2ch->date = ochusha_utils_get_utc_time(status->date);
     }
 
   ochusha_async_buffer_active_unref(buffer);
@@ -1584,6 +1688,11 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
   if (thread->board->bbs_type == OCHUSHA_BBS_TYPE_2CH_HEADLINE)
     thread->number_of_responses_read = 0;
 
+  if (be_pattern != NULL)
+    onig_free(be_pattern);
+  if (match_region != NULL)
+    onig_region_free(match_region, 1);
+
   return TRUE;
 }
 
@@ -1620,6 +1729,7 @@ ochusha_thread_2ch_get_url_for_response(OchushaBBSThread *thread, int from,
     case OCHUSHA_BBS_TYPE_2CH_COMPATIBLE:
     case OCHUSHA_BBS_TYPE_2CH_HEADLINE:
     case OCHUSHA_BBS_TYPE_2CHLIKE_EUCJP:
+    case OCHUSHA_BBS_TYPE_2CH_BE:
       {
 	if (from >= to)
 	  snprintf(url, PATH_MAX, "../test/read.cgi/%s/%s/%d",
@@ -1739,22 +1849,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   bbs = ochusha_bulletin_board_get_id(thread->board);
   key = thread->id;
 
-  if (thread_2ch->date != NULL)
-    time = ochusha_utils_get_utc_time(thread_2ch->date);
-  else
-    {
-#if DEBUG_POST
-      char message[4096];
-      snprintf(message, 4096, "thread_2ch(%s)->date == NULL\n",
-	       thread->title);
-      ochusha_network_broker_output_log(broker, message);
-#endif
-#if DEBUG_POST_MOST
-      fprintf(stderr, "thread_2ch->date == NULL!\n");
-#endif
-      time = ochusha_utils_get_utc_time(thread_2ch->last_modified);
-    }
-
+  time = thread_2ch->date;
   if (time == -1)
     goto error_exit;
 
@@ -1766,7 +1861,8 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 							    key, time);
   else
     {
-      if (use_id && broker->config->login_2ch)
+      if (use_id && broker->config->login_2ch
+	  && thread->board->bbs_type == OCHUSHA_BBS_TYPE_2CH)
 	query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&sid=%s&time=%ld", from, mail, message, bbs, key, broker->config->session_id_2ch, time);
       else
 	query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
@@ -1775,7 +1871,7 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
   if (query == NULL)
     goto error_exit;
 
-  post_result = ochusha_utils_2ch_try_post(broker, thread->board, query);
+  post_result = ochusha_utils_2ch_try_post(broker, thread->board, query, key);
   if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
     {
       if (ochusha_board_2ch_get_cookie(board_2ch) != NULL)
@@ -1788,9 +1884,9 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 	      else
 		query = g_strdup_printf("submit=%%91%%53%%90%%D3%%94%%43%%82%%F0%%95%%89%%82%%A4%%82%%B1%%82%%C6%%82%%F0%%8F%%B3%%91%%F8%%82%%B5%%82%%C4%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
 	    }
-	  sleep(10);
+	  sleep(30);
 	  post_result = ochusha_utils_2ch_try_post(broker, thread->board,
-						   query);
+						   query, key);
 	}
       else
 	{
@@ -1803,7 +1899,8 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
     {
       /* XXX: äݤΤȤͭʤΤ֡ */
       sleep(30);
-      post_result = ochusha_utils_2ch_try_post(broker, thread->board, query);
+      post_result
+	= ochusha_utils_2ch_try_post(broker, thread->board, query, key);
     }
 #endif
 
