@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.h,v 1.9.2.1 2004/06/11 12:00:48 fuyu Exp $
+ * $Id: ochusha_thread_2ch.h,v 1.9.2.2 2005/08/01 06:07:39 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_THREAD_2CH_H_
@@ -72,7 +72,7 @@ struct _OchushaThread2ch
   unsigned int responses_length;
 
   char *last_modified;	/* DATեɤ߹߻Last-Modifiedإå */
-  char *date;		/* 񤭹߻˻Ȥ */
+  time_t date;		/* 񤭹߻˻Ȥ */
 
   /* ιŪ˻Ȥ */
   gboolean alive;
