@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_jbbs.c,v 1.38.2.4 2004/12/30 14:16:38 fuyu Exp $
+ * $Id: ochusha_thread_jbbs.c,v 1.38.2.8 2005/08/01 06:07:39 fuyu Exp $
  */
 
 #include "config.h"
@@ -54,7 +54,7 @@
 # include <oniguruma.h>
 #endif
 
-#if (ONIGURUMA_VERSION_MAJOR < 2) || (ONIGURUMA_VERSION_MINOR < 2)
+#if (ONIGURUMA_VERSION_MAJOR < 2) && (ONIGURUMA_VERSION_MINOR < 2)
 #error "Please use included oniguruma, we no longer support oniguruma prior to 2.2"
 #endif
 
@@ -730,24 +730,27 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
 	    /*
 	     * GUIΥ쥹ݥ󥹤βܻؤ¸
 	     */
-	    OCHU_OBJECT_REF(buffer);
-	    g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
-	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
-			    advance_parsing, buffer, NULL);
-	    if (before_wait_cb != NULL)
-	      (*before_wait_cb)(callback_data);
-	    do
+	    if (!no_wait)
 	      {
-		if (!ochusha_async_buffer_wait(buffer))
+		OCHU_OBJECT_REF(buffer);
+		g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
+		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
+				advance_parsing, buffer, NULL);
+		if (before_wait_cb != NULL)
+		  (*before_wait_cb)(callback_data);
+		do
 		  {
-		    if (after_wait_cb != NULL)
-		      (*after_wait_cb)(callback_data);
-		    goto terminated;
-		  }
-	      } while (g_object_get_qdata(G_OBJECT(buffer), idle_checker_id)
-		       != NULL);
-	    if (after_wait_cb != NULL)
-	      (*after_wait_cb)(callback_data);
+		    if (!ochusha_async_buffer_wait(buffer))
+		      {
+			if (after_wait_cb != NULL)
+			  (*after_wait_cb)(callback_data);
+			goto terminated;
+		      }
+		  } while (g_object_get_qdata(G_OBJECT(buffer), idle_checker_id)
+			   != NULL);
+		if (after_wait_cb != NULL)
+		  (*after_wait_cb)(callback_data);
+	      }
 	    interval = ANALYSIS_INTERVAL;
 	  }
 
@@ -777,12 +780,7 @@ ochusha_thread_jbbs_parse_responses(OchushaBBSThread *thread,
     }
 
   if (status->date != NULL)
-    {
-      if (thread_2ch->date != NULL)
-	G_FREE(thread_2ch->date);
-      thread_2ch->date = G_STRDUP(status->date);
-    }
-
+    thread_2ch->date = ochusha_utils_get_utc_time(status->date);
   ochusha_async_buffer_active_unref(buffer);
 
   if (end_thread_cb != NULL)
@@ -1015,49 +1013,45 @@ typedef struct _HTML2DATConverterJobArgs
 } HTML2DATConverterJobArgs;
 
 
-static const char *title_pattern_string = NULL;
+static const char * const title_pattern_string = "<title>(.*)</title>";
 static const char *title_pattern_end = NULL;
-static const char *jbbs_shitaraba_response_pattern_string = NULL;
+
+#define NAME_EUCJP	"\314\276\301\260\241\247"	   /* "̾" */
+#define DATE_EUCJP	"\305\352\271\306\306\374\241\247" /* "" */
+static const char * const jbbs_shitaraba_response_pattern_string
+    = "(?i:<dt><a href[^>]*>)([1-9][0-9]*)(?i:</a>) " NAME_EUCJP
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
+      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
 static const char *jbbs_shitaraba_response_pattern_end = NULL;
-static const char *machibbs_response_pattern_string = NULL;
-static const char *machibbs_response_pattern_end = NULL;
-static const char *mitinoku_response_pattern_string = NULL;
+
+static const char * const mitinoku_response_pattern_string
+    = "(?i:<dt>)([1-9][0-9]*) " NAME_EUCJP
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
+      "(.*)(?i:<dd>)(.*)(?i:<br><br>)$";
 static const char *mitinoku_response_pattern_end = NULL;
 
+#define NAME_SJIS	"\226\274\221\117\201\106"	   /* "̾" */
+#define DATE_SJIS	"\223\212\215\145\223\372\201\106" /* "" */
+static const char * const machibbs_response_pattern_string
+    = "(?i:<dt>)([1-9][0-9]*) " NAME_SJIS
+      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_SJIS
+      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
+static const char *machibbs_response_pattern_end = NULL;
+
 
 static void
 initialize_default_regexp_patterns(void)
 {
-  title_pattern_string = "<title>(.*)</title>";
   title_pattern_end = title_pattern_string + strlen(title_pattern_string);
 
-#define NAME_EUCJP	"\314\276\301\260\241\247"	   /* "̾" */
-#define DATE_EUCJP	"\305\352\271\306\306\374\241\247" /* "" */
-
-  jbbs_shitaraba_response_pattern_string
-    = "(?i:<dt><a href[^>]*>)([1-9][0-9]*)(?i:</a>) " NAME_EUCJP
-      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
-      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
   jbbs_shitaraba_response_pattern_end
     = (jbbs_shitaraba_response_pattern_string
        + strlen(jbbs_shitaraba_response_pattern_string));
 
-  mitinoku_response_pattern_string
-    = "(?i:<dt>)([1-9][0-9]*) " NAME_EUCJP
-      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_EUCJP
-      "(.*)(?i:<dd>)(.*)(?i:<br><br>)$";
   mitinoku_response_pattern_end
     = (mitinoku_response_pattern_string
        + strlen(mitinoku_response_pattern_string));
 
-
-#define NAME_SJIS	"\226\274\221\117\201\106"	   /* "̾" */
-#define DATE_SJIS	"\223\212\215\145\223\372\201\106" /* "" */
-
-  machibbs_response_pattern_string
-    = "(?i:<dt>)([1-9][0-9]*) " NAME_SJIS
-      "[^<]*(<(?i:font)[^>]*|<(?i:a)[^>]*)>(.*)" DATE_SJIS
-      " (.*)(?i:<br><dd>)(.*)(?i:<br><br>)$";
   machibbs_response_pattern_end
     = (machibbs_response_pattern_string
        + strlen(machibbs_response_pattern_string));
@@ -1080,8 +1074,9 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
   regex_t *title_pattern = NULL;
   regex_t *response_pattern = NULL;
   OnigRegion *match_region = NULL;
+  char *previous_line = NULL;
 
-  if (title_pattern_string == NULL)
+  if (title_pattern_end == NULL)
     initialize_default_regexp_patterns();
 
   switch (thread->board->bbs_type)
@@ -1208,7 +1203,6 @@ convert_html_to_dat(WorkerThread *employee, HTML2DATConverterJobArgs *args)
       char *html_buffer_pos = html_buffer_top + html_offset;
       int rest_of_data = html_buffer->length - html_offset;
       char *eol_pos = NULL;
-      char *previous_line = NULL;
 
 #if DEBUG_HTML_TO_DAT_CONVERTER_MOST
       fprintf(stderr,
@@ -1629,7 +1623,7 @@ ochusha_thread_jbbs_fake_responses_source(OchushaThread2ch *thread_2ch,
   const char *fake_dat_url = ochusha_thread_2ch_get_dat_url(thread_2ch);
   WorkerJob *job;
   HTML2DATConverterJobArgs *args;
-  int incoming_offset;
+  int incoming_offset = 0;
   int number_of_cached_responses = 0;
   char cgi_url[PATH_MAX];
 
