@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.13 2004/12/30 14:15:50 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.15 2005/06/06 18:59:22 fuyu Exp $
  */
 
 #include "config.h"
@@ -1113,6 +1113,16 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 	       broker->config->session_id_2ch_be, cookie);
       cookie = cookie_buf;
     }
+#if DEBUG_POST
+  if (cookie != NULL)
+    {
+      ochusha_network_broker_output_log(broker, "Cookie: ");
+      ochusha_network_broker_output_log(broker, cookie);
+      ochusha_network_broker_output_log(broker, "\n");
+    }
+  else
+    ochusha_network_broker_output_log(broker, "No Cookie!\n");
+#endif
   post_result = ochusha_network_broker_try_post(broker, url,
 				ochusha_bulletin_board_get_server(board),
 				ochusha_bulletin_board_get_base_url(board),
@@ -1179,12 +1189,8 @@ ochusha_utils_2ch_try_post(OchushaNetworkBroker *broker,
 		  new_cookie = post_status.set_cookie;
 		  if (new_cookie != NULL && *new_cookie != '\0')
 		    {
-		      char *pos = strchr(new_cookie, ';');
-		      if (pos != NULL)
-			{
-			  *pos = '\0';
-			  ochusha_board_2ch_set_cookie(board_2ch, new_cookie);
-			}
+		      char *tmp_str = ochusha_utils_canon_cookie(new_cookie);
+		      ochusha_board_2ch_set_cookie(board_2ch, tmp_str);
 		    }
 		}
 
