@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.h,v 1.10 2004/01/30 22:55:47 fuyu Exp $
+ * $Id: ochusha_utils_2ch.h,v 1.10.2.2 2004/11/25 08:59:46 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UTILS_2CH_H_
@@ -77,11 +77,16 @@ typedef enum
 OchushaUtils2chPostResult ochusha_utils_2ch_try_post(
 						OchushaNetworkBroker *broker,
 						OchushaBulletinBoard *board,
-						const char *message);
+						const char *message,
+						const char *key);
 void ochusha_utils_2ch_login(OchushaConfig *config,
 			     OchushaNetworkBroker *broker,
 			     const char *user_id, const char *passwd);
 void ochusha_utils_2ch_logout(OchushaConfig *config);
+void ochusha_utils_2ch_be_login(OchushaConfig *config,
+				OchushaNetworkBroker *broker,
+				const char *user_id, const char *passwd);
+void ochusha_utils_2ch_be_logout(OchushaConfig *config);
 
 #ifdef __cplusplus
 } // extern "C"
