@@ -25,18 +25,18 @@
  */
 
 /*
- * This is a modified version of GtkNotebook from GTK+-2.2.1 by the
+ * This is a modified version of GtkNotebook from GTK+-2.6.1 by the
  * Ochusha Project.  See the AUTHORS file for a list of people on the
  * Ochusha Project.  See the ChangeLog files for a list of changes.
  * These files are distributed with ochusha at
- * http://home.att.ne.jp/wood/fuyu/.
+ * http://ochusha.sourceforge.jp/.
  *
  * Since libmodifiedgtk2 only has limited set of modified widgets and
  * is intended to be used with original GTK+, I don't want to cause name
  * space conflictions with original widget sets from GTK+.  Therefore,
  * ALL PUBLICLY AVAILABLE NAMES ARE RENAMED.
  *
- * $Id: mod_notebook.h,v 1.1.1.1 2003/05/10 16:34:29 fuyu Exp $
+ * $Id: mod_notebook.h,v 1.2.6.2 2005/02/23 14:11:22 fuyu Exp $
  */
 
 #ifndef __MOD_NOTEBOOK_H__
@@ -77,7 +77,8 @@ struct _ModNotebook
   ModNotebookPage *active_tips_page;
   GtkWidget *tip_window;
   GtkWidget *tip_label;
-  gint timer_tag;
+  gint tip_timer;
+  gint tip_hide_timer;
   GTimeVal last_popdown;
   
   guint32 timer;
@@ -92,17 +93,27 @@ struct _ModNotebook
   guint show_border        : 1;
   guint tab_pos            : 2;
   guint scrollable         : 1;
-  guint in_child           : 2;
-  guint click_child        : 2;
+  guint in_child           : 3;
+  guint click_child        : 3;
   guint button             : 2;
   guint need_timer         : 1;
   guint child_has_focus    : 1;
   guint have_visible_child : 1;
   guint focus_out          : 1;	/* Flag used by ::move-focus-out implementation */
-  guint tab_shrinkable     : 1;
-  guint enable_tooltips    : 1;
-  guint use_sticky_delay   : 1;
-  guint delay              : 30;
+
+  guint has_before_previous : 1;
+  guint has_before_next     : 1;
+  guint has_after_previous  : 1;
+  guint has_after_next      : 1;
+
+  guint tab_shrinkable      : 1;
+  guint enable_tooltips     : 1;
+  guint use_sticky_delay    : 1;
+  guint enable_close_button : 1;
+  guint in_close_button     : 1;
+  guint click_close_button  : 1;
+
+  guint delay;
 };
 
 struct _ModNotebookClass
@@ -114,20 +125,20 @@ struct _ModNotebookClass
 			      guint            page_num);
 
   /* Action signals for keybindings */
-  gboolean (* select_page)     (ModNotebook       *notebook,
-                                gboolean           move_focus);
-  gboolean (* focus_tab)       (ModNotebook       *notebook,
-                                GtkNotebookTab     type);
-  void (* change_current_page) (ModNotebook       *notebook,
-                                gint               offset);
-  void (* move_focus_out)      (ModNotebook       *notebook,
-				GtkDirectionType   direction);
+  gboolean (* select_page)      (ModNotebook       *notebook,
+                                 gboolean           move_focus);
+  gboolean (* focus_tab)        (ModNotebook       *notebook,
+                                 GtkNotebookTab     type);
+  void (* change_current_page)  (ModNotebook       *notebook,
+                                 gint               offset);
+  void (* move_focus_out)       (ModNotebook       *notebook,
+				 GtkDirectionType   direction);
+  void (* close_button_clicked) (ModNotebook       *notebook);
 
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
   void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
 };
 
 /***********************************************************
@@ -136,25 +147,25 @@ struct _ModNotebookClass
 
 GType   mod_notebook_get_type       (void) G_GNUC_CONST;
 GtkWidget * mod_notebook_new        (void);
-void mod_notebook_append_page       (ModNotebook *notebook,
+gint mod_notebook_append_page       (ModNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label);
-void mod_notebook_append_page_menu  (ModNotebook *notebook,
+gint mod_notebook_append_page_menu  (ModNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     GtkWidget   *menu_label);
-void mod_notebook_prepend_page      (ModNotebook *notebook,
+gint mod_notebook_prepend_page      (ModNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label);
-void mod_notebook_prepend_page_menu (ModNotebook *notebook,
+gint mod_notebook_prepend_page_menu (ModNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     GtkWidget   *menu_label);
-void mod_notebook_insert_page       (ModNotebook *notebook,
+gint mod_notebook_insert_page       (ModNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     gint         position);
-void mod_notebook_insert_page_menu  (ModNotebook *notebook,
+gint mod_notebook_insert_page_menu  (ModNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     GtkWidget   *menu_label,
@@ -217,6 +228,13 @@ void mod_notebook_popup_disable (ModNotebook *notebook);
 void mod_notebook_tooltips_enable  (ModNotebook *notebook);
 void mod_notebook_tooltips_disable (ModNotebook *notebook);
 
+/***********************************************************
+ *            enable/disable Close Button for Tabs         *
+ ***********************************************************/
+
+void mod_notebook_close_button_enable  (ModNotebook *notebook);
+void mod_notebook_close_button_disable (ModNotebook *notebook);
+
 /***********************************************************
  *             query/set NotebookPage Properties           *
  ***********************************************************/
