@@ -2,13 +2,17 @@
 
   reggnu.c -  Oniguruma (regular expression library)
 
-  Copyright (C) 2002-2003  K.Kosako (kosako@sofnec.co.jp)
+  Copyright (C) 2002-2004  K.Kosako (kosako AT sofnec DOT co DOT jp)
 
 **********************************************************************/
 #include "regint.h"
 
+#ifndef ONIGGNU_H     /* name changes from oniggnu.h to regex.h in ruby. */
+#include "oniggnu.h"
+#endif
+
 #if defined(RUBY_PLATFORM) || defined(RUBY)
-#ifndef REG_RUBY_M17N
+#ifndef ONIG_RUBY_M17N
 #define USE_COMPATIBILITY_FOR_RUBY_EXTENSION_LIBRARY
 #endif
 #endif
@@ -18,25 +22,25 @@
 #endif
 
 extern void
-re_free_registers(RegRegion* r)
+re_free_registers(OnigRegion* r)
 {
   /* 0: don't free self */
-  regex_region_free(r, 0);
+  onig_region_free(r, 0);
 }
 
 extern int
 re_adjust_startpos(regex_t* reg, const char* string, int size,
 		   int startpos, int range)
 {
-  if (startpos > 0 && ENC_MBC_MAXLEN(reg->enc) != 1 && startpos < size) {
+  if (startpos > 0 && ONIGENC_MBC_MAXLEN(reg->enc) != 1 && startpos < size) {
     UChar *p;
     UChar *s = (UChar* )string + startpos;
 
     if (range > 0) {
-      p = enc_get_right_adjust_char_head(reg->enc, (UChar* )string, s);
+      p = onigenc_get_right_adjust_char_head(reg->enc, (UChar* )string, s);
     }
     else {
-      p = ENC_LEFT_ADJUST_CHAR_HEAD(reg->enc, (UChar* )string, s);
+      p = ONIGENC_LEFT_ADJUST_CHAR_HEAD(reg->enc, (UChar* )string, s);
     }
     return p - (UChar* )string;
   }
@@ -48,29 +52,30 @@ extern int
 re_match(regex_t* reg, const char* str, int size, int pos,
 	 struct re_registers* regs)
 {
-  return regex_match(reg, (UChar* )str, (UChar* )(str + size),
-		     (UChar* )(str + pos), regs, REG_OPTION_NONE);
+  return onig_match(reg, (UChar* )str, (UChar* )(str + size),
+		    (UChar* )(str + pos), regs, ONIG_OPTION_NONE);
 }
 
 extern int
 re_search(regex_t* bufp, const char* string, int size, int startpos, int range,
 	  struct re_registers* regs)
 {
-  return regex_search(bufp, (UChar* )string, (UChar* )(string + size),
-		  (UChar* )(string + startpos),
-		  (UChar* )(string + startpos + range), regs, REG_OPTION_NONE);
+  return onig_search(bufp, (UChar* )string, (UChar* )(string + size),
+		     (UChar* )(string + startpos),
+		     (UChar* )(string + startpos + range),
+		     regs, ONIG_OPTION_NONE);
 }
 
 extern int
 re_compile_pattern(const char* pattern, int size, regex_t* reg, char* ebuf)
 {
   int r;
-  RegErrorInfo einfo;
+  OnigErrorInfo einfo;
 
-  r = regex_compile(reg, (UChar* )pattern, (UChar* )(pattern + size), &einfo);
+  r = onig_compile(reg, (UChar* )pattern, (UChar* )(pattern + size), &einfo);
   if (r != 0) {
     if (IS_NOT_NULL(ebuf))
-      (void )regex_error_code_to_str((UChar* )ebuf, r, &einfo);
+      (void )onig_error_code_to_str((UChar* )ebuf, r, &einfo);
   }
 
   return r;
@@ -80,19 +85,19 @@ extern int
 re_recompile_pattern(const char* pattern, int size, regex_t* reg, char* ebuf)
 {
   int r;
-  RegErrorInfo einfo;
-  RegCharEncoding enc;
+  OnigErrorInfo einfo;
+  OnigEncoding enc;
 
   /* I think encoding and options should be arguments of this function.
      But this is adapted to present re.c. (2002/11/29)
    */
-  enc = EncDefaultCharEncoding;
+  enc = OnigEncDefaultCharEncoding;
 
-  r = regex_recompile(reg, (UChar* )pattern, (UChar* )(pattern + size),
-		      reg->options, enc, RegDefaultSyntax, &einfo);
+  r = onig_recompile(reg, (UChar* )pattern, (UChar* )(pattern + size),
+		     reg->options, enc, OnigDefaultSyntax, &einfo);
   if (r != 0) {
     if (IS_NOT_NULL(ebuf))
-      (void )regex_error_code_to_str((UChar* )ebuf, r, &einfo);
+      (void )onig_error_code_to_str((UChar* )ebuf, r, &einfo);
   }
   return r;
 }
@@ -100,20 +105,20 @@ re_recompile_pattern(const char* pattern, int size, regex_t* reg, char* ebuf)
 extern void
 re_free_pattern(regex_t* reg)
 {
-  regex_free(reg);
+  onig_free(reg);
 }
 
 extern int
 re_alloc_pattern(regex_t** reg)
 {
-  return regex_alloc_init(reg, REG_OPTION_DEFAULT, EncDefaultCharEncoding,
-			  RegDefaultSyntax);
+  return onig_alloc_init(reg, ONIG_OPTION_DEFAULT, OnigEncDefaultCharEncoding,
+			 OnigDefaultSyntax);
 }
 
 extern void
 re_set_casetable(const char* table)
 {
-  enc_set_default_caseconv_table((UChar* )table);
+  onigenc_set_default_caseconv_table((UChar* )table);
 }
 
 #ifdef USE_COMPATIBILITY_FOR_RUBY_EXTENSION_LIBRARY
@@ -197,39 +202,39 @@ const unsigned char *re_mbctab = mbctab_ascii;
 #endif
 
 extern void
-#ifdef REG_RUBY_M17N
-re_mbcinit(RegCharEncoding enc)
+#ifdef ONIG_RUBY_M17N
+re_mbcinit(OnigEncoding enc)
 #else
 re_mbcinit(int mb_code)
 #endif
 {
-#ifdef REG_RUBY_M17N
+#ifdef ONIG_RUBY_M17N
 
-  enc_set_default_encoding(enc);
+  onigenc_set_default_encoding(enc);
 
 #else
 
-  RegCharEncoding enc;
+  OnigEncoding enc;
 
   switch (mb_code) {
   case MBCTYPE_ASCII:
-    enc = REG_ENCODING_ASCII;
+    enc = ONIG_ENCODING_ASCII;
     break;
   case MBCTYPE_EUC:
-    enc = REG_ENCODING_EUC_JP;
+    enc = ONIG_ENCODING_EUC_JP;
     break;
   case MBCTYPE_SJIS:
-    enc = REG_ENCODING_SJIS;
+    enc = ONIG_ENCODING_SJIS;
     break;
   case MBCTYPE_UTF8:
-    enc = REG_ENCODING_UTF8;
+    enc = ONIG_ENCODING_UTF8;
     break;
   default:
     return ;
     break;
   }
 
-  enc_set_default_encoding(enc);
+  onigenc_set_default_encoding(enc);
 #endif
 
 #ifdef USE_COMPATIBILITY_FOR_RUBY_EXTENSION_LIBRARY
